@@ -1,8 +1,7 @@
 package Workflow::Action;
 
 # Note: we may implement a separate event mechanism so that actions
-# can trigger other code (use 'Class::Observable'? read observations
-# from database?)
+# can trigger other code (to read observations from database?)
 
 use warnings;
 use strict;
@@ -13,7 +12,7 @@ use Workflow::Validator::HasRequiredField;
 use Workflow::Factory qw( FACTORY );
 use Carp qw(croak);
 
-$Workflow::Action::VERSION = '1.50';
+$Workflow::Action::VERSION = '1.51';
 
 my @PROPS    = qw( name class description );
 my @INTERNAL = qw( _factory );
@@ -161,13 +160,15 @@ sub init {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::Action - Base class for Workflow actions
 
 =head1 VERSION
 
-This documentation describes version 1.09 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -280,7 +281,7 @@ You can validate it like this:
     my $config = shift;
     unless ('NOW' eq $config->{when}) {
       configuration_error "`$$config{when}' is not a valid value " .
-		          "for `when'";
+                          "for `when'";
     }
   }
 
@@ -441,20 +442,27 @@ states you should return a simple scalar for a return value.
 Method to add fields to the workflow. The method takes an array of
 fields.
 
-
 =head1 SEE ALSO
 
-L<Workflow>
+=over
 
-L<Workflow::Factory>
+=item * L<Workflow>
+
+=item * L<Workflow::Factory>
+
+=back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2004 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Please see L<Workflow>
+
+=cut
