@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use base qw( Workflow::Action );
 
-$Workflow::Action::Mailer::VERSION = '1.50';
+$Workflow::Action::Mailer::VERSION = '1.51';
 
 sub execute {
     my ($self) = @_;
@@ -15,13 +15,15 @@ sub execute {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::Action::Mailer - a stub for a SMTP capable action
 
 =head1 VERSION
 
-This documentation describes version 1.01 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -47,15 +49,15 @@ I<Currently a stub>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
-
-Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
+Please see L<Workflow>
 
 =cut
