@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use base qw( Workflow::Action );
 
-$Workflow::Action::Null::VERSION = '1.50';
+$Workflow::Action::Null::VERSION = '1.51';
 
 sub execute {
     my ($self) = @_;
@@ -15,13 +15,15 @@ sub execute {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::Action::Null - Workflow action for the terminally lazy
 
 =head1 VERSION
 
-This documentation describes version 1.03 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -58,13 +60,15 @@ it by returning C<undef>.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2004 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
-
+Please see L<Workflow>
 
+=cut
