@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use base qw( Class::Accessor );
 use Log::Log4perl;
-$Workflow::Base::VERSION = '1.50';
+$Workflow::Base::VERSION = '1.51';
 
 sub new {
     my ( $class, @params ) = @_;
@@ -90,13 +90,15 @@ sub normalize_array {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::Base - Base class with constructor
 
 =head1 VERSION
 
-This documentation describes version 1.08 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -192,11 +194,15 @@ it in a list. If given neither return an empty list.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2004 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Please see L<Workflow>
+
+=cut
