@@ -6,7 +6,7 @@ use base qw( Workflow::Base );
 use Carp qw(croak);
 
 $Workflow::Condition::CACHE_RESULTS = 1;
-$Workflow::Condition::VERSION = '1.50';
+$Workflow::Condition::VERSION = '1.51';
 
 my @FIELDS = qw( name class );
 __PACKAGE__->mk_accessors(@FIELDS);
@@ -29,13 +29,15 @@ sub evaluate {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::Condition - Evaluate a condition depending on the workflow state and environment
 
 =head1 VERSION
 
-This documentation describes version 1.07 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -209,21 +211,21 @@ to zero (0):
 
     $Workflow::Condition::CACHE_RESULTS = 0;
 
-All versions before 1.50 used a mechanism that effectively caused global
+All versions before 1.49 used a mechanism that effectively caused global
 state. To address the problems that resulted (see GitHub issues #9 and #7),
-1.50 switched to a new mechanism with a cache per workflow instance.
+1.49 switched to a new mechanism with a cache per workflow instance.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
-
-Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
+Please see L<Workflow>
 
 =cut
