@@ -5,7 +5,7 @@ use strict;
 use base qw( Class::Accessor );
 use DateTime;
 
-$Workflow::History::VERSION = '1.50';
+$Workflow::History::VERSION = '1.51';
 
 my @FIELDS
     = qw( id workflow_id action description date user state time_zone );
@@ -58,13 +58,15 @@ sub clear_saved {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::History - Recorded work on a workflow action or workflow itself
 
 =head1 VERSION
 
-This documentation describes version 1.10 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -175,19 +177,23 @@ Sets saved state to true and returns 1
 
 =head1 SEE ALSO
 
-L<Workflow>
+=over
+
+=item * L<Workflow>
+
+=back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
-
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Please see L<Workflow>
 
 =cut
