@@ -9,7 +9,7 @@ use Workflow::Exception qw( persist_error );
 
 use constant DEFAULT_ID_LENGTH => 8;
 
-$Workflow::Persister::VERSION = '1.50';
+$Workflow::Persister::VERSION = '1.51';
 
 my @FIELDS = qw( name class
     use_random use_uuid
@@ -150,13 +150,15 @@ sub rollback_transaction {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::Persister - Base class for workflow persistence
 
 =head1 VERSION
 
-This documentation describes version 1.09 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -200,6 +202,8 @@ Persister. Since this is a SUPER class.
 Generate an ID for the workflow, serialize the workflow data (ID and
 state) and set the ID in the workflow.
 
+Returns the ID for the workflow.
+
 =head3 update_workflow( $workflow )
 
 Stub that warns that the method should be overwritten in the derived
@@ -207,13 +211,16 @@ Persister. Since this is a SUPER class.
 
 Update the workflow state.
 
+Returns nothing.
+
 =head3 fetch_workflow( $workflow_id )
 
 Stub that warns that the method should be overwritten in the derived
 Persister. Since this is a SUPER class.
 
 Retrieve the workflow data corresponding to C<$workflow_id>. It not
-found return undef, if found return a hashref with the data.
+found return undef, if found return a hashref with at least the keys
+C<state> and C<last_update> (a L<DateTime> instance).
 
 =head3 create_history( $workflow, @history )
 
@@ -222,6 +229,9 @@ Persister. Since this is a SUPER class.
 
 Serialize all objects in C<@history> for later retrieval.
 
+Returns C<@history>, the list of history objects, with the history
+C<id> and C<saved> values set according to the saved results.
+
 =head3 fetch_history( $workflow )
 
 Stub that warns that the method should be overwritten in the derived
@@ -311,21 +321,25 @@ we shift parameters in?
 
 =head1 SEE ALSO
 
-L<Workflow::Factory>
+=over
 
-L<Workflow::History>
+=item * L<Workflow::Factory>
+
+=item * L<Workflow::History>
+
+=back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
-
-Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
+Please see L<Workflow>
 
 =cut
