@@ -11,7 +11,7 @@ use Workflow::Persister::RandomId;
 use File::Slurp qw(slurp);
 use English qw( -no_match_vars );
 
-$Workflow::Persister::File::VERSION = '1.50';
+$Workflow::Persister::File::VERSION = '1.51';
 
 my @FIELDS = qw( path );
 __PACKAGE__->mk_accessors(@FIELDS);
@@ -51,6 +51,7 @@ sub create_workflow {
     my $full_history_path = $self->_get_history_path($wf);
     mkdir( $full_history_path, 0777 )
         || persist_error "Cannot create history dir '$full_history_path': $!";
+
     return $wf_id;
 }
 
@@ -193,13 +194,15 @@ sub _get_history_path {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::Persister::File - Persist workflow and history to the filesystem
 
 =head1 VERSION
 
-This documentation describes version 1.10 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -303,19 +306,23 @@ to deserialization attempt.
 
 =head1 SEE ALSO
 
-L<Workflow::Persister>
+=over
+
+=item * L<Workflow::Persister>
+
+=back
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Jonas B. Nielsen (jonasbn) E<lt>jonasbn@cpan.orgE<gt> is the current maintainer.
-
-Chris Winters E<lt>chris@cwinters.comE<gt>, original author.
+Please see L<Workflow>
 
 =cut
