@@ -8,7 +8,7 @@ use constant DEFAULT_ID_LENGTH  => 8;
 use constant RANDOM_SEED        => 26;
 use constant CONSTANT_INCREMENT => 65;
 
-$Workflow::Persister::RandomId::VERSION = '1.50';
+$Workflow::Persister::RandomId::VERSION = '1.51';
 
 my @FIELDS = qw( id_length );
 __PACKAGE__->mk_accessors(@FIELDS);
@@ -34,13 +34,15 @@ sub post_fetch_id {return}
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::Persister::RandomId - Persister to generate random ID
 
 =head1 VERSION
 
-This documentation describes version 1.03 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -82,11 +84,15 @@ This method is unimplemented at this time, please see the TODO.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2004 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Please see L<Workflow>
+
+=cut
