@@ -5,7 +5,7 @@ use strict;
 use base qw( Workflow::Validator );
 use Workflow::Exception qw( configuration_error validation_error );
 
-$Workflow::Validator::InEnumeratedType::VERSION = '1.50';
+$Workflow::Validator::InEnumeratedType::VERSION = '1.51';
 
 sub _init {
     my ( $self, $params ) = @_;
@@ -51,13 +51,15 @@ sub is_enumerated_value {
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Workflow::Validator::InEnumeratedType - Ensure a value is one of a declared set of values
 
 =head1 VERSION
 
-This documentation describes version 1.04 of this package
+This documentation describes version 1.51 of this package
 
 =head1 SYNOPSIS
 
@@ -213,15 +215,15 @@ part of the set.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2003-2007 Chris Winters. All rights reserved.
+Copyright (c) 2003-2021 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+Please see the F<LICENSE>
+
 =head1 AUTHORS
 
-Current maintainer Jonas B. Nielsen E<lt>jonasbn@cpan.orgE<gt>
-
-Original author Chris Winters E<lt>chris@cwinters.comE<gt>
-
+Please see L<Workflow>
 
+=cut
